==> powertools-1.0.tar.bz2: html/modules/News/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","ǰe");
define("_URL","}");
define("_PRINTER","͵CL榡");
define("_FRIEND","HB");



define("_YOURNAME","zWr");

define("_OK","Tw");
define("_RELATED","쵲");
define("_MOREABOUT","h");
define("_NEWSBY","sDӷ");
define("_MOSTREAD","̨w諸ɡA");
define("_READMORE","ԲӤe...");
define("_BYTESMORE","줸");
define("_COMMENTSQ","ѷNH");
define("_COMMENT","N");

define("_CONFIGURE","]w");
define("_LOGINCREATE","nJ/ͷsb");
define("_THRESHOLD","e");
define("_NOCOMMENTS","ܷN");
define("_NESTED","_");
define("_FLAT","Z");
define("_THREAD","u");
define("_OLDEST","ª");
define("_NEWEST","s");
define("_HIGHEST","");
define("_COMMENTSWARNING","ۧ@vݩ@̡A鷺etd");
define("_SCORE","ơG");


define("_USERINFO","ϥΪ̸T");
define("_READREST","\תl...");
define("_REPLY","^");
define("_REPLYMAIN","o");
define("_NOSUBJECT","LD");
define("_NOANONCOMMENTS","\ΦWo, Х <a href=\"modules.php?name=Your_Account&amp;op=new_user\">U</a>");
define("_PARENT","_");
define("_ROOT","");

define("_UCOMMENT","");
define("_ALLOWEDHTML","\HTMLykG");
define("_POSTANON","ΦWo");
define("_EXTRANS","Extrans (html tags to )");
define("_HTMLFORMATED","HTML榡");
define("_PLAINTEXT","@r榡");
define("_ONN","...");
define("_SUBJECT","D");
define("_COMMENTREPLY","No");
define("_COMREPLYPRE","Now");
define("_NOTRIGHT","ƥܼơITȨѰѦ");
define("_SENDAMSG","HXT");
define("_YOUSENDSTORY","zNHX");
define("_TOAFRIEND","̡G");
define("_FYOURNAME","zmWG");
define("_FYOUREMAIL","z E-mailG");
define("_FFRIENDNAME","zBͪmWG");
define("_FFRIENDEMAIL","zBͪ E-mailG");
define("_INTERESTING","P쪺峹b");
define("_HELLO","");
define("_YOURFRIEND","zB");
define("_CONSIDERED","ıoog峹AMz@P");
define("_FDATE","G");
define("_FTOPIC","sDDDG");
define("_YOUCANREAD","ШӦ\Ūog쪺峹");
define("_FSTORY","");
define("_HASSENT","wQHX");
define("_THANKS","¡I");
define("_RECOMMEND","˥B");
define("_PDATE","G");
define("_PTOPIC","sDDDG");
define("_COMESFROM","峹Ӧ۩");
define("_THEURL","oɪ}OG");





define("_PREVIEW","w");
define("_NEWUSER","sϥΪ");
define("_OPTIONS","ﶵ");


define("_REFRESH","sz");
define("_ADD","sW");
define("_NOCOMMENTSACT","藍_, ثeog峹LkܷN.");
define("_ARTICLEPOLL","媺벼");
define("_RATEARTICLE","峹");
define("_RATETHISARTICLE","Ъ@ǮɶoǤ峹:");
define("_CASTMYVOTE","ڤ@!");
define("_AVERAGESCORE","");
define("_BAD","n");
define("_REGULAR","q");
define("_GOOD","n");
define("_VERYGOOD","ܦn");
define("_EXCELLENT","D`n");
define("_ARTICLERATING","峹");
define("_THANKSVOTEARTICLE","§A벼!");
define("_ALREADYVOTEDARTICLE","藍_,A̪wgL峹!");
define("_BACKTOARTICLEPAGE","^峹");
define("_DIDNTRATE","AåܥƵog峹!");
define("_NOINFO4TOPIC","藍_, AܪDDèST.");
define("_GOTONEWSINDEX","^sD");
define("_SELECTNEWTOPIC","ܤ@ӷsDD");
define("_GOTOHOME","^쭺");
define("_SEARCHONTOPIC","jMoӥDD");
define("_SEARCHDIS","MDQץDD");

?>

==> powertools-1.0.1.tar.bz2: html/modules/News/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","ǰe");
define("_URL","}");
define("_PRINTER","͵CL榡");
define("_FRIEND","HB");
define("_YOURNAME","zWr");
define("_OK","Tw");
define("_RELATED","쵲");
define("_MOREABOUT","h");
define("_NEWSBY","sDӷ");
define("_MOSTREAD","̨w諸ɡA");
define("_READMORE","ԲӤe...");
define("_BYTESMORE","줸");
define("_COMMENTSQ","ѷNH");
define("_COMMENT","N");
define("_CONFIGURE","]w");
define("_LOGINCREATE","nJ/ͷsb");
define("_THRESHOLD","e");
define("_NOCOMMENTS","ܷN");
define("_NESTED","_");
define("_FLAT","Z");
define("_THREAD","u");
define("_OLDEST","ª");
define("_NEWEST","s");
define("_HIGHEST","");
define("_COMMENTSWARNING","ۧ@vݩ@̡A鷺etd");
define("_SCORE","ơG");
define("_USERINFO","ϥΪ̸T");
define("_READREST","\תl...");
define("_REPLY","^");
define("_REPLYMAIN","o");
define("_NOSUBJECT","LD");
define("_NOANONCOMMENTS","\ΦWo, Х <a href=\"modules.php?name=Your_Account\">U</a>");
define("_PARENT","_");
define("_ROOT","");
define("_UCOMMENT","");
define("_ALLOWEDHTML","\HTMLykG");
define("_POSTANON","ΦWo");
define("_EXTRANS","Extrans (html tags to )");
define("_HTMLFORMATED","HTML榡");
define("_PLAINTEXT","@r榡");
define("_ONN","...");
define("_SUBJECT","D");
define("_COMMENTREPLY","No");
define("_COMREPLYPRE","Now");
define("_NOTRIGHT","ƥܼơITȨѰѦ");
define("_SENDAMSG","HXT");
define("_YOUSENDSTORY","zNHX");
define("_TOAFRIEND","̡G");
define("_FYOURNAME","zmWG");
define("_FYOUREMAIL","z E-mailG");
define("_FFRIENDNAME","zBͪmWG");
define("_FFRIENDEMAIL","zBͪ E-mailG");
define("_INTERESTING","쪺峹b");
define("_HELLO","");
define("_YOURFRIEND","zB");
define("_CONSIDERED","ıoog峹AMz@P");
define("_FDATE","G");
define("_FTOPIC","sDDDG");
define("_YOUCANREAD","ШӦ\Ūog쪺峹");
define("_FSTORY","");
define("_HASSENT","wQHX");
define("_THANKS","¡I");
define("_RECOMMEND","˥B");
define("_PDATE","G");
define("_PTOPIC","sDDDG");
define("_COMESFROM","峹Ӧ۩");
define("_THEURL","oɪ}OG");
define("_PREVIEW","w");
define("_NEWUSER","sϥΪ");
define("_OPTIONS","ﶵ");
define("_REFRESH","sz");
define("_ADD","sW");
define("_NOCOMMENTSACT","藍_, ثeog峹LkܷN.");
define("_ARTICLEPOLL","媺벼");
define("_RATEARTICLE","峹");
define("_RATETHISARTICLE","Ъ@og峹@ӤơG");
define("_CASTMYVOTE","eX!");
define("_AVERAGESCORE","");
define("_BAD","t");
define("_REGULAR","@");
define("_GOOD","n");
define("_VERYGOOD","D`n");
define("_EXCELLENT","");
define("_ARTICLERATING","峹");
define("_THANKSVOTEARTICLE","h±zog峹w!");
define("_ALREADYVOTEDARTICLE","藍_AA̪~Log峹ƩOI");
define("_BACKTOARTICLEPAGE","^峹eI");
define("_DIDNTRATE","z٨Sܤƭ!");
define("_NOINFO4TOPIC","藍_AzܪDD|LTC");
define("_GOTONEWSINDEX","^sD");
define("_SELECTNEWTOPIC","ܷsDD");
define("_GOTOHOME","^쭺");
define("_SEARCHONTOPIC","boӥDDjM");
define("_SEARCHDIS","jMQ");
define("_READPDF","Read as PDF");
define("_READWITHCOMMENTS", "You can read the complete story with its comments from");
define("_TOFINISHRATING","To finish the rating process and to let the system count your vote, please complete the requested information:");
define("_TOFINISHRATINGERROR","<b>ERROR:</b> The security code you wrote is incorrect...<br>Please write it exactly as given bellow:");
define("_YOURATEDARTICLE","Your vote was");
define("_COMMENTSMODERATION","Comments Moderation System");
define("_MODERATE","Moderate");
define("_CLICKTOMODERATE","Please select your moderation values for each comment on this article, then click on <i>Moderate</i> button bellow to save your comments moderation preferences. Be fair on each value, this will contribute and benefict all users/readers. Thank you.");
define("_COMMENTSSYSTEM","Comments System");
define("_COMMENTPOSTERROR","<b>Error saving your comment...</b><br><br><b>ERROR:</b> The title or the main text of your comment are empty.<br>Please go back and correct the problem, then try again.");

?>
